@@ -26,8 +26,8 @@ testKappaTau <- function(rho, wExp) {
     rho2 <- if (wExp == 2) psi2propII(rho) else rho
     kappa <- calcKappaTau(rho2, 1)
     fun <- switch(wExp,
-                  function(x) rho@psi(x)*x - kappa*rho@wgt(x),
-                  function(x) rho@psi(x)^2 - kappa*rho@wgt(x)^2)
+                  function(x) rho$psi(x)*x - kappa*rho$wgt(x),
+                  function(x) rho$psi(x)^2 - kappa*rho$wgt(x)^2)
     E(fun)
 }
 
@@ -36,7 +36,7 @@ testKappa <- function(rho) {
               all.equal(0, testKappaTau(rho, 2), tolerance = 1e-4))
 }
 
-testKappa(huberPsi)
+testKappa(huberPsiRcpp)
 testKappa(smoothPsi)
 
 E2 <- function(fun, ...) {
@@ -48,7 +48,7 @@ E2 <- function(fun, ...) {
 rfm <- rlmer(Yield ~ (1|Batch), Dyestuff)
 
 testTau <- function(rho, rho.sigma, wExp, a, s) {
-    psi <- rho@psi
+    psi <- rho$psi
     rho.e <- rho.sigma
     rho.sigma2 <- if (wExp == 2) psi2propII(rho.sigma) else rho.sigma
     kappa <- calcKappaTau(rho.sigma2, 1)
@@ -56,18 +56,18 @@ testTau <- function(rho, rho.sigma, wExp, a, s) {
 
     fun <- switch(wExp + 1,
                   { ## wExp.e == 0:
-                      wgt <- function(x) ifelse(x == 0, rho.e@Dpsi(0)/2, rho@rho(x)/(x*x))
+                      wgt <- function(x) ifelse(x == 0, rho.e$Dpsi(0)/2, rho$rho(x)/(x*x))
                       function(w, v, tau) {
                           t <- (v-a[i]*psi(v)+w*s[i])/tau
-                          rho.e@rho(t) - kappa*wgt(t)
+                          rho.e$rho(t) - kappa*wgt(t)
                       } }, ## wExp.e == 1:
                   function(w, v, tau) {
                       t <- (v-a[i]*psi(v)+w*s[i])/tau
-                      rho.e@psi(t)*t - kappa*rho.e@wgt(t)
+                      rho.e$psi(t)*t - kappa*rho.e$wgt(t)
                   }, ## wExp.e == 2:
                   function(w, v, tau) {
                       t <- (v-a[i]*psi(v)+w*s[i])/tau
-                      rho.e@psi(t)^2 - kappa*rho.e@wgt(t)^2
+                      rho.e$psi(t)^2 - kappa*rho.e$wgt(t)^2
                   })
 
     tau <- calcTau(a, s, rho, rho.sigma2, rfm@pp, kappa)
@@ -82,10 +82,10 @@ testTau <- function(rho, rho.sigma, wExp, a, s) {
 a <- c(0.1, 0.4, 1, 1, 0.8)
 s <- c(0.4, 0.5, 0.8, 0.1, 0.1)
 ## FIXME: increase accuracy of calcTau.
-stopifnot(all.equal(rep(0, length(a)), testTau(huberPsi, huberPsi, 1, a, s), tolerance = 1e-2),
-          all.equal(rep(0, length(a)), testTau(huberPsi, huberPsi, 2, a, s), tolerance = 1e-2))
-stopifnot(all.equal(rep(0, length(a)), testTau(smoothPsi, huberPsi, 1, a, s), tolerance = 1e-2),
-          all.equal(rep(0, length(a)), testTau(smoothPsi, huberPsi, 2, a, s), tolerance = 1e-1))
+stopifnot(all.equal(rep(0, length(a)), testTau(huberPsiRcpp, huberPsiRcpp, 1, a, s), tolerance = 1e-2),
+          all.equal(rep(0, length(a)), testTau(huberPsiRcpp, huberPsiRcpp, 2, a, s), tolerance = 1e-2))
+stopifnot(all.equal(rep(0, length(a)), testTau(smoothPsi, huberPsiRcpp, 1, a, s), tolerance = 1e-2),
+          all.equal(rep(0, length(a)), testTau(smoothPsi, huberPsiRcpp, 2, a, s), tolerance = 1e-1))
 stopifnot(all.equal(rep(0, length(a)), testTau(smoothPsi, smoothPsi, 1, a, s), tolerance = 1e-2),
           all.equal(rep(0, length(a)), testTau(smoothPsi, smoothPsi, 2, a, s), tolerance = 1e-1))
 sPsi <- chgDefaults(smoothPsi, k = 1, s = 10)
